@@ -408,7 +408,8 @@ Ext.define('MP.data.MetaData', {
                 var store;
 
                 if(Ext.isArray(info.dictionary)) {
-                    store = info.dictionary;
+                    // Make a copy, so caller may safely alter it
+                    store = [].concat(info.dictionary);
                 } else {
                     var sortby = 0; // key by default
                     var dict = info.dictionary;
