@@ -14,6 +14,11 @@
  */
 Ext.define('MP.desktop.ShortcutModel', {
     extend: 'Ext.data.Model',
+    requires: [
+        // This seems strange but is really important: without this requirement the minificated
+        // application fails with an error, maybe due to glitches in the ExtJS classes metadata
+        'Ext.data.proxy.Ajax'
+    ],
     fields: [
        { name: 'name' },
        { name: 'iconCls' },
